#! /usr/bin/env python
#
#getspectrumandpeaksplot.py
#
#Copyright (c) 2014 by Micron Optics, Inc.  All Rights Reserved
#
"""This example will plot a spectrum and the corresponding peaks.  This
requires numpy, scilab, and matplotlib packages.
"""
import matplotlib
import numpy as np
import matplotlib.pyplot as plt
from scipy.interpolate import interp1d

import sys

import hyperion


channel = 1
scanRate = 5000
#change this IP address to match the instrument
h1 = hyperion.Hyperion('10.0.41.100', timeout=10000)


if h1.scanSpeed != scanRate:
    try:
        print 'Changing laser scan speed to {0}'.format(scanRate)
        h1.set_laser_scan_speed(scanRate)
        h1.comm.execute_command('#IsReady')
        pass
    except hyperion.HyperionError as e:
        print e

#get the peaks
peaks = h1.get_peaks()
ch1Peaks = peaks.get_channel(channel)
print ch1Peaks

#Get the spectrum
dbmData = h1.get_spectrum(channel)



#close the comm
h1.comm.close()


try:
    #We will interpolate the peak data so that the indicators appear on the
    #plot in line with the spectrum.
    interpSpectrum = interp1d(h1.wavelengths, dbmData)
except Exception as e:
    print e
else:
    plt.plot(h1.wavelengths, dbmData,ch1Peaks,interpSpectrum(ch1Peaks),'o')
    plt.xlabel('Wavelength (nm)')
    plt.ylabel('Amplitude (dBm)')
    plt.show()
